#
# spec file for package dmraid
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


#Compat macro for new _fillupdir macro introduced in Nov 2017
%if ! %{defined _fillupdir}
  %define _fillupdir /var/adm/fillup-templates
%endif

Name:           dmraid
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  device-mapper-devel
BuildRequires:  libselinux-devel
BuildRequires:  suse-module-tools
BuildRequires:  systemd-rpm-macros
BuildRequires:  zlib-devel

Requires:       aaa_base
Requires:       kpartx
Requires(post): coreutils
Requires(postun): coreutils
Url:            http://people.redhat.com/~heinzm/sw/dmraid/src/
Summary:        A Device-Mapper Software RAID Support Tool
License:        GPL-2.0
Group:          System/Base
Version:        1.0.0.rc16
Release:        40.1
Source:         ftp://people.redhat.com/heinzm/sw/dmraid/src/dmraid-%{version}.tar.bz2
Source1:        sysconfig.dmraid
Source3:        README.SUSE
Source6:        dmraid-activation.service
Patch1:         dmraid-1.0.0.rc16-cvs-2010-02-02.patch
Patch2:         dmraid-1.0.0.rc13-geometry.patch
Patch3:         lib-install.patch
Patch4:         handle_spaces
Patch5:         remove_trylock
Patch6:         rebuild.fix
Patch7:         ddf-erase
Patch8:         dmraid-move-var-lock-to-run-lock.patch
Patch9:         dmraid-destdir.patch
Patch10:        fix-undefined-symbol.patch
Patch11:        0001-remove-partitions-with-O_RDONLY.patch

BuildRoot:      %{_tmppath}/%{name}-%{version}-build
PreReq:         %fillup_prereq
%{systemd_requires}

%description
This software discovers, activates, deactivates, and displays
properties of software RAID sets, such as ATARAID, and contained DOS
partitions.

dmraid uses libdevmapper and the device-mapper kernel runtime to create
devices with respective mappings for the ATARAID sets discovered.

The following ATARAID types are supported:

- Highpoint HPT37X

- Highpoint HPT45X

- Intel Software RAID

- Promise FastTrak

- Silicon Image Medley

%package devel
Summary:        Development files for dmraid
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}

%description devel
This software discovers, activates, deactivates, and displays
properties of software RAID sets, such as ATARAID, and contained DOS
partitions.

dmraid uses libdevmapper and the device-mapper kernel runtime to create
devices with respective mappings for the ATARAID sets discovered.

%prep
%setup -n dmraid/%{version}
%patch1 -p1
%patch2 -p1
%patch3 -p1
%patch4 -p1
%patch5 -p2
%patch6 -p1
%patch7 -p1
%patch8 -p1
%patch9 -p1
%patch10 -p1
%patch11 -p2

cp %{SOURCE3} .

%build
#rm -f aclocal.m4
autoreconf -fi
rm -r autom4te.cache
%configure \
  --libdir=/%_lib \
  --sbindir=/sbin \
  --with-user=`id -nu` --with-group=`id -ng` \
  --enable-libselinux --enable-libsepol
make

%install
make install DESTDIR=$RPM_BUILD_ROOT
rm -f $RPM_BUILD_ROOT/%_lib/libdmraid.a
mkdir -p $RPM_BUILD_ROOT%{_fillupdir}
install -m644 %{SOURCE1} $RPM_BUILD_ROOT%{_fillupdir}/sysconfig.dmraid
install -D -m 0644 %{S:6} %{buildroot}%{_unitdir}/dmraid-activation.service
install -d %{buildroot}%{_tmpfilesdir}
echo 'd /run/lock/dmraid 0700 root root -' > %{buildroot}%{_tmpfilesdir}/dmraid.conf
# E: spurious-executable-perm (Badness: 50) /usr/include/dmraid/locking.h
chmod -x %{buildroot}%{_prefix}/include/dmraid/*h

%pre
%service_add_pre dmraid-activation.service

%preun
%service_del_preun dmraid-activation.service

%post
/sbin/ldconfig
%service_add_post dmraid-activation.service
%{?regenerate_initrd_post}

%posttrans
%{?regenerate_initrd_posttrans}

%{fillup_only}

%postun
/sbin/ldconfig
%service_del_postun dmraid-activation.service
%{?regenerate_initrd_post}

%files
%defattr(-, root, root)
/sbin/dmraid
/sbin/dmevent_tool
%{_mandir}/man8/*
%doc LICENSE LICENSE_GPL LICENSE_LGPL README README.SUSE TODO doc/*
%{_fillupdir}/sysconfig.dmraid
/%{_lib}/libdmraid-events-isw.so
/%{_lib}/libdmraid.so.1.0.0.rc16-3
%dir %{_tmpfilesdir}
%{_tmpfilesdir}/dmraid.conf
%{_unitdir}/dmraid-activation.service

%files devel
%defattr(-, root, root)
%dir %{_prefix}/include/dmraid
%{_prefix}/include/dmraid
/%{_lib}/libdmraid.so

%changelog
* Thu Nov 23 2017 rbrown@suse.com
- Replace references to /var/adm/fillup-templates with new
  %%_fillupdir macro (boo#1069468)
* Thu Oct 26 2017 mwilck@suse.com
- dmraid: remove partitions with O_RDONLY
  * add 0001-remove-partitions-with-O_RDONLY.patch
* Sat Feb 18 2017 kukuk@suse.com
- Remove obsolete insserv call
* Thu Dec 10 2015 tiwai@suse.de
- Fix missing dependency on coreutils for initrd macros (boo#958562)
- Call missing initrd macro at postun (boo#958562)
* Mon Jul 13 2015 lwang@suse.com
- dmevent_tool fails with "undefined symbol" (bnc#935623)
  Added: fix-undefined-symbol.patch
* Wed Feb  4 2015 coolo@suse.com
- remove with -f to avoid dependency on local umask
* Fri Dec 12 2014 kkaempf@suse.com
- Split off dmraid-devel subpackage
* Mon Nov 10 2014 dimstar@opensuse.org
- Own /usr/lib/tmpfiles.d: in the past, we were lucky for another
  package in the build dependency chain to own this for us, but in
  fact we should do it ourselves.
* Fri Jul 25 2014 jeffm@suse.com
- Rename README.SuSE to README.SUSE (bnc#889025).
* Fri Jun 13 2014 trenn@suse.de
- Use rpm macros to only trigger one initrd rebuild per install/update
* Wed May 21 2014 jsegitz@novell.com
- added necessary macros for systemd files
* Fri Sep 13 2013 crrodriguez@opensuse.org
- Fix Makefiles so they support DESTDIR
  Added: dmraid-destdir.patch
- add tmpfiles.d so runtime directories are properly created
- Remove sysvinit support and replace it for native systemd support.
  Added: dmraid-activation.service
  Removed: boot.dmraid
* Tue Jul 23 2013 ohering@suse.de
- Remove usage of absolute paths in initrd
- Remove some checks from mkinitrd scripts, they are always true
- List all used binaries in programs tag
* Wed Nov 28 2012 rmilasan@suse.com
- Move lock file to /run/lock so it wont interfere with systemd.
* Mon Jul  9 2012 cfarrell@suse.com
- license update: GPL-2.0
  See lib/register/dmreg.c and tools/dmevent_tool.c (both have GPL-2.0
  license)
* Mon Jan  9 2012 aj@suse.de
- Add automake as buildrequires.
* Tue Dec 20 2011 coolo@suse.com
- add autoconf as buildrequire to avoid implicit dependency
* Wed Sep 21 2011 nfbrown@suse.com
- rebuild.fix: When a rebuild is requested that
  cannot be handled, report and error instead of
  crashing (bnc#716904)
- ddf-erase: Allow dmraid to erase ddf metadata
  properly (bnc#712671)
* Fri May 27 2011 lnussel@suse.de
- don't hard require boot.device-mapper in boot.dmraid. dm-mod is
  autoloaded when accessing /dev/mapper/control anyways.
* Mon Apr 19 2010 nfbrown@novell.com
- handle_space: cope with arrays with spaces in the name stored
  in the metadata (bnc#470696)
- remove_trylock: pthreads_mutex_trylock is still very new in
  glibc so safest not to use it yet (bnc#594388)
* Tue Feb  2 2010 nfbrown@novell.com
- new upstream version, including latest CVS updates.
  Both libdmraid-events and dm_dso_reg_tool are not
  in the main package.
- dm_dso_reg_tool has been renamed to dmevent_tool in
  line with upstream change.
  bnc#528796 bnc#511329
* Mon Oct  5 2009 crrodriguez@opensuse.org
- fix a few more fdleaks [bnc#543151]
* Sat Oct  3 2009 crrodriguez@opensuse.org
- fix directory handle leaks in libdmraid-events [bnc#524202]
* Mon Aug 24 2009 hvogel@novell.com
- Fix activation of isw raid sets when the disks have serialnumber
  longer then 16 characters
- Add patch adding --rm_partitions cmdline option and functionality
- Fix mismatch between BIOS and dmraid's view of ISW raid 10 sets
* Sun Aug  2 2009 jansimon.moeller@opensuse.org
- The cmdline options don't work when compiling the events module
  on ARM. Add patch to directly include the ldflags in the
  Makefile.
* Mon Nov 24 2008 hare@suse.de
- Properly quote mkinitrd scripts (bnc#447966)
* Mon Nov 10 2008 mkoenig@suse.de
- adapt mkinitrd script to changed UUID prefix [bnc#441479]
* Tue Oct 14 2008 mkoenig@suse.de
- remove whitespace from serial id [bnc#433833]
* Thu Sep 25 2008 mkoenig@suse.de
- update to 1.0.0rc15
  * jm.c: fixed name handling
  * nv.c: fixed endian bug
  * added support for RAID set create/remove/rebuild and
    event handling
- needed for [fate#304215,fate#303950,fate#304216]
- removed patches
  dmraid-1.0.0.rc13-jm_termination.patch
  dmraid-1.0.0.rc14-ddf1_segfault.patch
  dmraid-add_uuid.patch
  dmraid_fixup_nvidia.diff
  dmraid-move-type-definition.diff
  dmraid-pdc_max_sectors.patch
* Wed Sep 24 2008 ro@suse.de
- change "udevsettle" to "udevadm settle"
* Tue Sep 16 2008 mkoenig@suse.de
- ignore the timestamp for LSI 1068E DDF1 metadata [bnc#426615]
* Mon Sep 15 2008 ro@suse.de
- fix typo in libdmraid Makefile
- split off libdmraid-events0 package according to
  shared library packaging policy
* Sat Sep 13 2008 meissner@suse.de
- symlink, not copy the .so to the .so.0 file
- removed self-provides, some other .spec file fixes
* Wed Sep 10 2008 xwhu@novell.com
- Adding DSO for event-handling [fate#304214]
* Wed Sep  3 2008 hare@suse.de
- Call mkinitrd_setup during %%post and %%postun (bnc#413709)
* Wed Aug 20 2008 mkoenig@suse.de
- enable SELinux support [fate#303662]
* Wed Aug 13 2008 mkoenig@suse.de
- fix init script tags
* Wed Jul 23 2008 hare@suse.de
- Include mkinitrd scriptlets.
* Wed Mar 12 2008 mkoenig@suse.de
- add hack to avoid segfault with DDF1 metadata and explicit
  indication of the raid set [#367686]
* Wed Sep 12 2007 mkoenig@suse.de
- add quirk for maximum detected device size of some pdc card
  [#215222]
* Tue Jul 31 2007 hare@suse.de
- dmraid requires kpartx.
* Mon Jul 30 2007 hare@suse.de
- Do not activate partitions from dmraid; udev handles it.
* Tue Jul 10 2007 mkoenig@suse.de
- update to version 1.0.0.rc14
  * bugfix release
* Tue Jun 19 2007 mkoenig@suse.de
- use boot.localfs to avoid expansion problem
* Tue Jun 19 2007 mkoenig@suse.de
- Add X-Start-Before: $local_fs dependency
* Thu Mar 29 2007 mkoenig@suse.de
- Add zlib-devel to BuildRequires
* Tue Feb 20 2007 mkoenig@suse.de
- provide boot script [#230708]
* Mon Dec 11 2006 mkoenig@suse.de
- fix jm name string termination problem [#223843]
  patch: dmraid-1.0.0.rc13-jm_termination.patch
- fix min, max macros
  patch: dmraid-1.0.0.rc13-fix_macro.patch
* Thu Nov 23 2006 mkoenig@suse.de
- fix geometry patch [#222110]
* Mon Nov 20 2006 mkoenig@suse.de
- set geometry of dm device [#222110]
* Thu Nov  9 2006 mkoenig@suse.de
- update to version 1.0.0.rc13
  * Fixes for Promise FastTrak and Silicon Image Medley ATARAID
  * Support for SNIA DDF1 and JBOD
* Wed Sep 13 2006 ro@suse.de
- use device-mapper-devel in BuildRequires
* Tue Aug 29 2006 hare@suse.de
- update to 1.0.0-rc11
- NVidia endianness fixes
- Add UUID to device-mapper tables
- Fixup '-cc' argument
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Dec  5 2005 kukuk@suse.de
- Remove unused klibc-devel from neededforbuild
* Wed Jul 13 2005 cadaha@suse.de
- update to 1.0.0-rc8, fix big endian build
* Tue Sep 21 2004 cadaha@suse.de
- fix dmraid -rc output for unsupported devices
* Mon Sep 20 2004 cadaha@suse.de
- created package
